.. cofi-espresso documentation master file, created by
   sphinx-quickstart on Fri Jun  3 13:47:44 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to the documentation of Espresso!
=========================================

Espresso is a collection of clearly defined forward codes
that simulate physical processes from many disciplines within the geosciences
and elsewhere. The goal of Espresso is to 
bring together people developing physical simulations with those who need them.
Espresso's simple and consistent code structure enables users to access a wide range
of different forward code and contributors to share their solutions with a wider
audience. Having the basic set up and several examples in
place already, we hope to encourage more examples be developed and be contributed.



.. toctree::
    :caption: Guides
    :maxdepth: 1

    installation.rst
    faq.rst

.. toctree::
    :caption: Reference
    :maxdepth: 2

    contrib/index.rst

.. toctree::
    :caption: Development
    :maxdepth: 1

    contribute.rst
    licence.rst


.. Indices and tables
.. ==================

.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
